import{p as e,f as o}from"./flowDb-956e92f1-4f08b38e.js";import{f as t,g as a}from"./styles-c10674c1-b7110364.js";import{u as i}from"./index-c941dcb3.js";import"./graph-ee94449e.js";import"./layout-a9aa9858.js";import"./index-3862675e-940162b4.js";import"./clone-78c82dea.js";import"./edges-e0da2a9e-9039bff9.js";import"./createText-2e5e7dd3-b0f4f0fe.js";import"./line-eb73cf26.js";import"./array-9f3ba611.js";import"./path-53f90ab3.js";import"./channel-8e08bed9.js";const M={parser:e,db:o,renderer:t,styles:a,init:r=>{r.flowchart||(r.flowchart={}),r.flowchart.arrowMarkerAbsolute=r.arrowMarkerAbsolute,i({flowchart:{arrowMarkerAbsolute:r.arrowMarkerAbsolute}}),t.setConf(r.flowchart),o.clear(),o.setGen("gen-2")}};export{M as diagram};
